@@ -2,6 +2,7 @@ import os
 import pytest
 from typing import List, Tuple
 
+from repro.common import docker
 from repro.common.util import NestedDict, flatten_nested_dict
 
 FIXTURES_ROOT = f"{os.path.dirname(os.path.abspath(__file__))}/../tests/fixtures"
@@ -28,3 +29,18 @@ def assert_dicts_approx_equal(
     assert d1.keys() == d2.keys()
     for key in d1.keys():
         assert d1[key] == pytest.approx(d2[key], rel=rel, abs=abs)
+
+
+class DockerTestContextManager(object):
+    def __init__(self, image: str):
+        self.image = image
+
+    def __enter__(self):
+        # Make sure the image doesn't exist. If it does, delete it
+        if docker.image_exists(self.image):
+            docker.remove_image(self.image, force=True)
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        # Make sure the image gets deleted
+        if docker.image_exists(self.image):
+            docker.remove_image(self.image, force=True)
